clip/help
Functions for building Help flags.
Types
Values
pub fn custom(f: fn(arg_info.ArgInfo) -> String) -> Help
Generate custom help text by providing a function that transforms
ArgInfo into a String.
Functions for building Help flags.
pub fn custom(f: fn(arg_info.ArgInfo) -> String) -> Help
Generate custom help text by providing a function that transforms
ArgInfo into a String.